# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ShapeCustom module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_shapecustom.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ShapeCustom
else:
    import _ShapeCustom

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ShapeCustom.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ShapeCustom.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ShapeCustom.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ShapeCustom.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ShapeCustom.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ShapeCustom.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ShapeCustom.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ShapeCustom.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ShapeCustom.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ShapeCustom.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ShapeCustom.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ShapeCustom.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ShapeCustom.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ShapeCustom.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ShapeCustom.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ShapeCustom.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ShapeCustom.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ShapeCustom:
_ShapeCustom.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ShapeCustom.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.GeomAbs
import OCC.Core.Geom
import OCC.Core.TColgp
import OCC.Core.Geom2d
import OCC.Core.BRepTools
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.TopTools
import OCC.Core.BRep
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.ShapeExtend
import OCC.Core.TColGeom

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_ShapeCustom_Modification_Create() -> "opencascade::handle< ShapeCustom_Modification >":
    return _ShapeCustom.Handle_ShapeCustom_Modification_Create()

def Handle_ShapeCustom_Modification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ShapeCustom_Modification >":
    return _ShapeCustom.Handle_ShapeCustom_Modification_DownCast(t)

def Handle_ShapeCustom_Modification_IsNull(t: "opencascade::handle< ShapeCustom_Modification > const &") -> "bool":
    return _ShapeCustom.Handle_ShapeCustom_Modification_IsNull(t)

def Handle_ShapeCustom_RestrictionParameters_Create() -> "opencascade::handle< ShapeCustom_RestrictionParameters >":
    return _ShapeCustom.Handle_ShapeCustom_RestrictionParameters_Create()

def Handle_ShapeCustom_RestrictionParameters_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ShapeCustom_RestrictionParameters >":
    return _ShapeCustom.Handle_ShapeCustom_RestrictionParameters_DownCast(t)

def Handle_ShapeCustom_RestrictionParameters_IsNull(t: "opencascade::handle< ShapeCustom_RestrictionParameters > const &") -> "bool":
    return _ShapeCustom.Handle_ShapeCustom_RestrictionParameters_IsNull(t)

def Handle_ShapeCustom_TrsfModification_Create() -> "opencascade::handle< ShapeCustom_TrsfModification >":
    return _ShapeCustom.Handle_ShapeCustom_TrsfModification_Create()

def Handle_ShapeCustom_TrsfModification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ShapeCustom_TrsfModification >":
    return _ShapeCustom.Handle_ShapeCustom_TrsfModification_DownCast(t)

def Handle_ShapeCustom_TrsfModification_IsNull(t: "opencascade::handle< ShapeCustom_TrsfModification > const &") -> "bool":
    return _ShapeCustom.Handle_ShapeCustom_TrsfModification_IsNull(t)

def Handle_ShapeCustom_ConvertToBSpline_Create() -> "opencascade::handle< ShapeCustom_ConvertToBSpline >":
    return _ShapeCustom.Handle_ShapeCustom_ConvertToBSpline_Create()

def Handle_ShapeCustom_ConvertToBSpline_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ShapeCustom_ConvertToBSpline >":
    return _ShapeCustom.Handle_ShapeCustom_ConvertToBSpline_DownCast(t)

def Handle_ShapeCustom_ConvertToBSpline_IsNull(t: "opencascade::handle< ShapeCustom_ConvertToBSpline > const &") -> "bool":
    return _ShapeCustom.Handle_ShapeCustom_ConvertToBSpline_IsNull(t)

def Handle_ShapeCustom_DirectModification_Create() -> "opencascade::handle< ShapeCustom_DirectModification >":
    return _ShapeCustom.Handle_ShapeCustom_DirectModification_Create()

def Handle_ShapeCustom_DirectModification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ShapeCustom_DirectModification >":
    return _ShapeCustom.Handle_ShapeCustom_DirectModification_DownCast(t)

def Handle_ShapeCustom_DirectModification_IsNull(t: "opencascade::handle< ShapeCustom_DirectModification > const &") -> "bool":
    return _ShapeCustom.Handle_ShapeCustom_DirectModification_IsNull(t)
class shapecustom(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def BSplineRestriction(*args) -> "TopoDS_Shape":
        r"""
        Returns a new shape with all surfaces, curves and pcurves which type is bspline/bezier or based on them converted having degree less than <maxdegree> or number of spans less than <nbmaxsegment> in dependence on parameter priority <degree>. <gmaxdegree> and <gmaxsegments> are maximum possible degree and number of spans correspondingly. these values will be used in those cases when approximation with specified parameters is impossible and one of gmaxdegree or gmaxsegments is selected in dependence on priority. note that even if approximation is impossible with <gmaxdegree> then number of spans can exceed specified <gmaxsegment> <rational> specifies if to convert rational bspline/bezier into polynomial b-spline. if flags convoffsurf,convoffcurve3d,convoffcurve2d are standard_true there are means that offset surfaces , offset curves 3d and offset curves 2d are converted to bspline correspondingly.

        Parameters
        ----------
        S: TopoDS_Shape
        Tol3d: float
        Tol2d: float
        MaxDegree: int
        MaxNbSegment: int
        Continuity3d: GeomAbs_Shape
        Continuity2d: GeomAbs_Shape
        Degree: bool
        Rational: bool
        aParameters: ShapeCustom_RestrictionParameters

        Returns
        -------
        TopoDS_Shape

        """
        return _ShapeCustom.shapecustom_BSplineRestriction(*args)

    @staticmethod
    def ConvertToBSpline(*args) -> "TopoDS_Shape":
        r"""
        Returns a new shape with all surfaces of linear extrusion, revolution, offset, and planar surfaces converted according to flags to geom_bsplinesurface (with same parameterisation).

        Parameters
        ----------
        S: TopoDS_Shape
        extrMode: bool
        revolMode: bool
        offsetMode: bool
        planeMode: bool,optional
        	default value is Standard_False

        Returns
        -------
        TopoDS_Shape

        """
        return _ShapeCustom.shapecustom_ConvertToBSpline(*args)

    @staticmethod
    def ConvertToRevolution(*args) -> "TopoDS_Shape":
        r"""
        Returns a new shape with all elementary periodic surfaces converted to geom_surfaceofrevolution.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _ShapeCustom.shapecustom_ConvertToRevolution(*args)

    @staticmethod
    def DirectFaces(*args) -> "TopoDS_Shape":
        r"""
        Returns a new shape without indirect surfaces.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _ShapeCustom.shapecustom_DirectFaces(*args)

    @staticmethod
    def ScaleShape(*args) -> "TopoDS_Shape":
        r"""
        Returns a new shape which is scaled original.

        Parameters
        ----------
        S: TopoDS_Shape
        scale: float

        Returns
        -------
        TopoDS_Shape

        """
        return _ShapeCustom.shapecustom_ScaleShape(*args)

    @staticmethod
    def SweptToElementary(*args) -> "TopoDS_Shape":
        r"""
        Returns a new shape with all surfaces of revolution and linear extrusion convert to elementary periodic surfaces.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        TopoDS_Shape

        """
        return _ShapeCustom.shapecustom_SweptToElementary(*args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def ApplyModifier(self):
    	pass


    def __init__(self):
        _ShapeCustom.shapecustom_swiginit(self, _ShapeCustom.new_shapecustom())
    __swig_destroy__ = _ShapeCustom.delete_shapecustom

# Register shapecustom in _ShapeCustom:
_ShapeCustom.shapecustom_swigregister(shapecustom)

def shapecustom_BSplineRestriction(*args) -> "TopoDS_Shape":
    r"""
    Returns a new shape with all surfaces, curves and pcurves which type is bspline/bezier or based on them converted having degree less than <maxdegree> or number of spans less than <nbmaxsegment> in dependence on parameter priority <degree>. <gmaxdegree> and <gmaxsegments> are maximum possible degree and number of spans correspondingly. these values will be used in those cases when approximation with specified parameters is impossible and one of gmaxdegree or gmaxsegments is selected in dependence on priority. note that even if approximation is impossible with <gmaxdegree> then number of spans can exceed specified <gmaxsegment> <rational> specifies if to convert rational bspline/bezier into polynomial b-spline. if flags convoffsurf,convoffcurve3d,convoffcurve2d are standard_true there are means that offset surfaces , offset curves 3d and offset curves 2d are converted to bspline correspondingly.

    Parameters
    ----------
    S: TopoDS_Shape
    Tol3d: float
    Tol2d: float
    MaxDegree: int
    MaxNbSegment: int
    Continuity3d: GeomAbs_Shape
    Continuity2d: GeomAbs_Shape
    Degree: bool
    Rational: bool
    aParameters: ShapeCustom_RestrictionParameters

    Returns
    -------
    TopoDS_Shape

    """
    return _ShapeCustom.shapecustom_BSplineRestriction(*args)

def shapecustom_ConvertToBSpline(*args) -> "TopoDS_Shape":
    r"""
    Returns a new shape with all surfaces of linear extrusion, revolution, offset, and planar surfaces converted according to flags to geom_bsplinesurface (with same parameterisation).

    Parameters
    ----------
    S: TopoDS_Shape
    extrMode: bool
    revolMode: bool
    offsetMode: bool
    planeMode: bool,optional
    	default value is Standard_False

    Returns
    -------
    TopoDS_Shape

    """
    return _ShapeCustom.shapecustom_ConvertToBSpline(*args)

def shapecustom_ConvertToRevolution(*args) -> "TopoDS_Shape":
    r"""
    Returns a new shape with all elementary periodic surfaces converted to geom_surfaceofrevolution.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    TopoDS_Shape

    """
    return _ShapeCustom.shapecustom_ConvertToRevolution(*args)

def shapecustom_DirectFaces(*args) -> "TopoDS_Shape":
    r"""
    Returns a new shape without indirect surfaces.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    TopoDS_Shape

    """
    return _ShapeCustom.shapecustom_DirectFaces(*args)

def shapecustom_ScaleShape(*args) -> "TopoDS_Shape":
    r"""
    Returns a new shape which is scaled original.

    Parameters
    ----------
    S: TopoDS_Shape
    scale: float

    Returns
    -------
    TopoDS_Shape

    """
    return _ShapeCustom.shapecustom_ScaleShape(*args)

def shapecustom_SweptToElementary(*args) -> "TopoDS_Shape":
    r"""
    Returns a new shape with all surfaces of revolution and linear extrusion convert to elementary periodic surfaces.

    Parameters
    ----------
    S: TopoDS_Shape

    Returns
    -------
    TopoDS_Shape

    """
    return _ShapeCustom.shapecustom_SweptToElementary(*args)

class ShapeCustom_Curve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        C: Geom_Curve

        Returns
        -------
        None

        """
        _ShapeCustom.ShapeCustom_Curve_swiginit(self, _ShapeCustom.new_ShapeCustom_Curve(*args))

    def ConvertToPeriodic(self, *args) -> "opencascade::handle< Geom_Curve >":
        r"""
        Tries to convert the curve to the periodic form returns the resulting curve works only if the curve is bspline and is closed with precision::confusion() else, or in case of failure, returns a null handle.

        Parameters
        ----------
        substitute: bool
        preci: float,optional
        	default value is -1

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _ShapeCustom.ShapeCustom_Curve_ConvertToPeriodic(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        C: Geom_Curve

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_Curve_Init(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_Curve

# Register ShapeCustom_Curve in _ShapeCustom:
_ShapeCustom.ShapeCustom_Curve_swigregister(ShapeCustom_Curve)

class ShapeCustom_Curve2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ConvertToLine2d(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &":
        r"""
        Try to convert bspline2d or bezier2d to line 2d only if it is linear. recalculate first and last parameters. returns line2d or null curve2d.

        Parameters
        ----------
        theCurve: Geom2d_Curve
        theFirstIn: float
        theLastIn: float
        theTolerance: float

        Returns
        -------
        theNewFirst: float
        theNewLast: float
        theDeviation: float

        """
        return _ShapeCustom.ShapeCustom_Curve2d_ConvertToLine2d(*args)

    @staticmethod
    def IsLinear(*args) -> "Standard_Real &":
        r"""
        Check if poleses is in the plane with given precision returns false if no.

        Parameters
        ----------
        thePoles: TColgp_Array1OfPnt2d
        theTolerance: float

        Returns
        -------
        theDeviation: float

        """
        return _ShapeCustom.ShapeCustom_Curve2d_IsLinear(*args)

    @staticmethod
    def SimplifyBSpline2d(*args) -> "Standard_Boolean":
        r"""
        Try to remove knots from bspline where local derivatives are the same. remove knots with given precision. returns false if bsplien was not modified.

        Parameters
        ----------
        theBSpline2d: Geom2d_BSplineCurve
        theTolerance: float

        Returns
        -------
        bool

        """
        return _ShapeCustom.ShapeCustom_Curve2d_SimplifyBSpline2d(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ShapeCustom.ShapeCustom_Curve2d_swiginit(self, _ShapeCustom.new_ShapeCustom_Curve2d())
    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_Curve2d

# Register ShapeCustom_Curve2d in _ShapeCustom:
_ShapeCustom.ShapeCustom_Curve2d_swigregister(ShapeCustom_Curve2d)

def ShapeCustom_Curve2d_ConvertToLine2d(*args) -> "Standard_Real &, Standard_Real &, Standard_Real &":
    r"""
    Try to convert bspline2d or bezier2d to line 2d only if it is linear. recalculate first and last parameters. returns line2d or null curve2d.

    Parameters
    ----------
    theCurve: Geom2d_Curve
    theFirstIn: float
    theLastIn: float
    theTolerance: float

    Returns
    -------
    theNewFirst: float
    theNewLast: float
    theDeviation: float

    """
    return _ShapeCustom.ShapeCustom_Curve2d_ConvertToLine2d(*args)

def ShapeCustom_Curve2d_IsLinear(*args) -> "Standard_Real &":
    r"""
    Check if poleses is in the plane with given precision returns false if no.

    Parameters
    ----------
    thePoles: TColgp_Array1OfPnt2d
    theTolerance: float

    Returns
    -------
    theDeviation: float

    """
    return _ShapeCustom.ShapeCustom_Curve2d_IsLinear(*args)

def ShapeCustom_Curve2d_SimplifyBSpline2d(*args) -> "Standard_Boolean":
    r"""
    Try to remove knots from bspline where local derivatives are the same. remove knots with given precision. returns false if bsplien was not modified.

    Parameters
    ----------
    theBSpline2d: Geom2d_BSplineCurve
    theTolerance: float

    Returns
    -------
    bool

    """
    return _ShapeCustom.ShapeCustom_Curve2d_SimplifyBSpline2d(*args)

class ShapeCustom_Modification(OCC.Core.BRepTools.BRepTools_Modification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def MsgRegistrator(self, *args) -> "opencascade::handle< ShapeExtend_BasicMsgRegistrator >":
        r"""
        Returns message registrator.

        Returns
        -------
        opencascade::handle<ShapeExtend_BasicMsgRegistrator>

        """
        return _ShapeCustom.ShapeCustom_Modification_MsgRegistrator(self, *args)

    def SendMsg(self, *args) -> "void":
        r"""
        Sends a message to be attached to the shape. calls corresponding message of message registrator.

        Parameters
        ----------
        shape: TopoDS_Shape
        message: Message_Msg
        gravity: Message_Gravity,optional
        	default value is Message_Info

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_Modification_SendMsg(self, *args)

    def SetMsgRegistrator(self, *args) -> "void":
        r"""
        Sets message registrator.

        Parameters
        ----------
        msgreg: ShapeExtend_BasicMsgRegistrator

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_Modification_SetMsgRegistrator(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeCustom_Modification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_Modification

# Register ShapeCustom_Modification in _ShapeCustom:
_ShapeCustom.ShapeCustom_Modification_swigregister(ShapeCustom_Modification)

class ShapeCustom_RestrictionParameters(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Sets default parameters.

        Returns
        -------
        None

        """
        _ShapeCustom.ShapeCustom_RestrictionParameters_swiginit(self, _ShapeCustom.new_ShapeCustom_RestrictionParameters(*args))

    def GetConvertBezierSurf(self) -> "Standard_Boolean":
        r"""GetConvertBezierSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertBezierSurf(self)

    def SetConvertBezierSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertBezierSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertBezierSurf(self, value)

    def GetConvertConicalSurf(self) -> "Standard_Boolean":
        r"""GetConvertConicalSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertConicalSurf(self)

    def SetConvertConicalSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertConicalSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertConicalSurf(self, value)

    def GetConvertCurve2d(self) -> "Standard_Boolean":
        r"""GetConvertCurve2d(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertCurve2d(self)

    def SetConvertCurve2d(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertCurve2d(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertCurve2d(self, value)

    def GetConvertCurve3d(self) -> "Standard_Boolean":
        r"""GetConvertCurve3d(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertCurve3d(self)

    def SetConvertCurve3d(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertCurve3d(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertCurve3d(self, value)

    def GetConvertCylindricalSurf(self) -> "Standard_Boolean":
        r"""GetConvertCylindricalSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertCylindricalSurf(self)

    def SetConvertCylindricalSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertCylindricalSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertCylindricalSurf(self, value)

    def GetConvertExtrusionSurf(self) -> "Standard_Boolean":
        r"""GetConvertExtrusionSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertExtrusionSurf(self)

    def SetConvertExtrusionSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertExtrusionSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertExtrusionSurf(self, value)

    def GetConvertOffsetCurv2d(self) -> "Standard_Boolean":
        r"""GetConvertOffsetCurv2d(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertOffsetCurv2d(self)

    def SetConvertOffsetCurv2d(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertOffsetCurv2d(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertOffsetCurv2d(self, value)

    def GetConvertOffsetCurv3d(self) -> "Standard_Boolean":
        r"""GetConvertOffsetCurv3d(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertOffsetCurv3d(self)

    def SetConvertOffsetCurv3d(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertOffsetCurv3d(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertOffsetCurv3d(self, value)

    def GetConvertOffsetSurf(self) -> "Standard_Boolean":
        r"""GetConvertOffsetSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertOffsetSurf(self)

    def SetConvertOffsetSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertOffsetSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertOffsetSurf(self, value)

    def GetConvertPlane(self) -> "Standard_Boolean":
        r"""GetConvertPlane(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertPlane(self)

    def SetConvertPlane(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertPlane(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertPlane(self, value)

    def GetConvertRevolutionSurf(self) -> "Standard_Boolean":
        r"""GetConvertRevolutionSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertRevolutionSurf(self)

    def SetConvertRevolutionSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertRevolutionSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertRevolutionSurf(self, value)

    def GetConvertSphericalSurf(self) -> "Standard_Boolean":
        r"""GetConvertSphericalSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertSphericalSurf(self)

    def SetConvertSphericalSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertSphericalSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertSphericalSurf(self, value)

    def GetConvertToroidalSurf(self) -> "Standard_Boolean":
        r"""GetConvertToroidalSurf(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetConvertToroidalSurf(self)

    def SetConvertToroidalSurf(self, value: "Standard_Boolean") -> "void":
        r"""SetConvertToroidalSurf(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetConvertToroidalSurf(self, value)

    def GetGMaxDegree(self) -> "Standard_Integer":
        r"""GetGMaxDegree(ShapeCustom_RestrictionParameters self) -> Standard_Integer"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetGMaxDegree(self)

    def SetGMaxDegree(self, value: "Standard_Integer") -> "void":
        r"""SetGMaxDegree(ShapeCustom_RestrictionParameters self, Standard_Integer value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetGMaxDegree(self, value)

    def GetGMaxSeg(self) -> "Standard_Integer":
        r"""GetGMaxSeg(ShapeCustom_RestrictionParameters self) -> Standard_Integer"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetGMaxSeg(self)

    def SetGMaxSeg(self, value: "Standard_Integer") -> "void":
        r"""SetGMaxSeg(ShapeCustom_RestrictionParameters self, Standard_Integer value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetGMaxSeg(self, value)

    def GetSegmentSurfaceMode(self) -> "Standard_Boolean":
        r"""GetSegmentSurfaceMode(ShapeCustom_RestrictionParameters self) -> Standard_Boolean"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_GetSegmentSurfaceMode(self)

    def SetSegmentSurfaceMode(self, value: "Standard_Boolean") -> "void":
        r"""SetSegmentSurfaceMode(ShapeCustom_RestrictionParameters self, Standard_Boolean value)"""
        return _ShapeCustom.ShapeCustom_RestrictionParameters_SetSegmentSurfaceMode(self, value)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeCustom_RestrictionParameters_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_RestrictionParameters

# Register ShapeCustom_RestrictionParameters in _ShapeCustom:
_ShapeCustom.ShapeCustom_RestrictionParameters_swigregister(ShapeCustom_RestrictionParameters)

class ShapeCustom_Surface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        S: Geom_Surface

        Returns
        -------
        None

        """
        _ShapeCustom.ShapeCustom_Surface_swiginit(self, _ShapeCustom.new_ShapeCustom_Surface(*args))

    def ConvertToAnalytical(self, *args) -> "opencascade::handle< Geom_Surface >":
        r"""
        Tries to convert the surface to an analytic form returns the result works only if the surface is bspline or bezier. else, or in case of failure, returns a null handle //! if <substitute> is true, the new surface replaces the actual one in <self> //! it works by analysing the case which can apply, creating the corresponding analytic surface, then checking coincidence warning: parameter laws are not kept, hence pcurves should be redone.

        Parameters
        ----------
        tol: float
        substitute: bool

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _ShapeCustom.ShapeCustom_Surface_ConvertToAnalytical(self, *args)

    def ConvertToPeriodic(self, *args) -> "opencascade::handle< Geom_Surface >":
        r"""
        Tries to convert the surface to the periodic form returns the resulting surface works only if the surface is bspline and is closed with precision::confusion() else, or in case of failure, returns a null handle.

        Parameters
        ----------
        substitute: bool
        preci: float,optional
        	default value is -1

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _ShapeCustom.ShapeCustom_Surface_ConvertToPeriodic(self, *args)

    def Gap(self, *args) -> "Standard_Real":
        r"""
        Returns maximal deviation of converted surface from the original one computed by last call to converttoanalytical.

        Returns
        -------
        float

        """
        return _ShapeCustom.ShapeCustom_Surface_Gap(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        S: Geom_Surface

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_Surface_Init(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_Surface

# Register ShapeCustom_Surface in _ShapeCustom:
_ShapeCustom.ShapeCustom_Surface_swigregister(ShapeCustom_Surface)

class ShapeCustom_TrsfModification(OCC.Core.BRepTools.BRepTools_TrsfModification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Parameters
        ----------
        T: gp_Trsf

        Returns
        -------
        None

        """
        _ShapeCustom.ShapeCustom_TrsfModification_swiginit(self, _ShapeCustom.new_ShapeCustom_TrsfModification(*args))


    @staticmethod
    def DownCast(t):
      return Handle_ShapeCustom_TrsfModification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_TrsfModification

# Register ShapeCustom_TrsfModification in _ShapeCustom:
_ShapeCustom.ShapeCustom_TrsfModification_swigregister(ShapeCustom_TrsfModification)

class ShapeCustom_ConvertToBSpline(ShapeCustom_Modification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ShapeCustom.ShapeCustom_ConvertToBSpline_swiginit(self, _ShapeCustom.new_ShapeCustom_ConvertToBSpline(*args))

    def SetExtrusionMode(self, *args) -> "void":
        r"""
        Sets mode for convertion of surfaces of linear extrusion.

        Parameters
        ----------
        extrMode: bool

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_ConvertToBSpline_SetExtrusionMode(self, *args)

    def SetOffsetMode(self, *args) -> "void":
        r"""
        Sets mode for convertion of offset surfaces.

        Parameters
        ----------
        offsetMode: bool

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_ConvertToBSpline_SetOffsetMode(self, *args)

    def SetPlaneMode(self, *args) -> "void":
        r"""
        Sets mode for convertion of plane surfaces.

        Parameters
        ----------
        planeMode: bool

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_ConvertToBSpline_SetPlaneMode(self, *args)

    def SetRevolutionMode(self, *args) -> "void":
        r"""
        Sets mode for convertion of surfaces of revolution.

        Parameters
        ----------
        revolMode: bool

        Returns
        -------
        None

        """
        return _ShapeCustom.ShapeCustom_ConvertToBSpline_SetRevolutionMode(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ShapeCustom_ConvertToBSpline_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_ConvertToBSpline

# Register ShapeCustom_ConvertToBSpline in _ShapeCustom:
_ShapeCustom.ShapeCustom_ConvertToBSpline_swigregister(ShapeCustom_ConvertToBSpline)

class ShapeCustom_DirectModification(ShapeCustom_Modification):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ShapeCustom.ShapeCustom_DirectModification_swiginit(self, _ShapeCustom.new_ShapeCustom_DirectModification(*args))


    @staticmethod
    def DownCast(t):
      return Handle_ShapeCustom_DirectModification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ShapeCustom.delete_ShapeCustom_DirectModification

# Register ShapeCustom_DirectModification in _ShapeCustom:
_ShapeCustom.ShapeCustom_DirectModification_swigregister(ShapeCustom_DirectModification)


@classnotwrapped
class ShapeCustom_BSplineRestriction:
	pass

@classnotwrapped
class ShapeCustom_SweptToElementary:
	pass

@classnotwrapped
class ShapeCustom_ConvertToRevolution:
	pass









from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Adaptor2d import *
from OCC.Core.math import *
from OCC.Core.gp import *


class CPnts_AbscissaPoint:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Abscissa: float, U0: float, Resolution: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Abscissa: float, U0: float, Resolution: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Abscissa: float, U0: float, Ui: float, Resolution: float) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Abscissa: float, U0: float, Ui: float, Resolution: float) -> None: ...
	def AdvPerform(self, Abscissa: float, U0: float, Ui: float, Resolution: float) -> None: ...
	@overload
	def Init(self, C: Adaptor3d_Curve) -> None: ...
	@overload
	def Init(self, C: Adaptor2d_Curve2d) -> None: ...
	@overload
	def Init(self, C: Adaptor3d_Curve, Tol: float) -> None: ...
	@overload
	def Init(self, C: Adaptor2d_Curve2d, Tol: float) -> None: ...
	@overload
	def Init(self, C: Adaptor3d_Curve, U1: float, U2: float) -> None: ...
	@overload
	def Init(self, C: Adaptor2d_Curve2d, U1: float, U2: float) -> None: ...
	@overload
	def Init(self, C: Adaptor3d_Curve, U1: float, U2: float, Tol: float) -> None: ...
	@overload
	def Init(self, C: Adaptor2d_Curve2d, U1: float, U2: float, Tol: float) -> None: ...
	def IsDone(self) -> bool: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve, Tol: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d, Tol: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve, U1: float, U2: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d, U1: float, U2: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor3d_Curve, U1: float, U2: float, Tol: float) -> float: ...
	@overload
	@staticmethod
	def Length(C: Adaptor2d_Curve2d, U1: float, U2: float, Tol: float) -> float: ...
	def Parameter(self) -> float: ...
	@overload
	def Perform(self, Abscissa: float, U0: float, Resolution: float) -> None: ...
	@overload
	def Perform(self, Abscissa: float, U0: float, Ui: float, Resolution: float) -> None: ...
	def SetParameter(self, P: float) -> None: ...

class CPnts_MyGaussFunction(math_Function):
	def __init__(self) -> None: ...
	def Init(self, F: CPnts_RealFunction, D: None) -> None: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...

class CPnts_MyRootFunction(math_FunctionWithDerivative):
	def __init__(self) -> None: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	@overload
	def Init(self, F: CPnts_RealFunction, D: None, Order: int) -> None: ...
	@overload
	def Init(self, X0: float, L: float) -> None: ...
	@overload
	def Init(self, X0: float, L: float, Tol: float) -> None: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

class CPnts_UniformDeflection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Deflection: float, Resolution: float, WithControl: bool) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Deflection: float, Resolution: float, WithControl: bool) -> None: ...
	@overload
	def __init__(self, C: Adaptor3d_Curve, Deflection: float, U1: float, U2: float, Resolution: float, WithControl: bool) -> None: ...
	@overload
	def __init__(self, C: Adaptor2d_Curve2d, Deflection: float, U1: float, U2: float, Resolution: float, WithControl: bool) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Deflection: float, Resolution: float, WithControl: bool) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Deflection: float, Resolution: float, WithControl: bool) -> None: ...
	@overload
	def Initialize(self, C: Adaptor3d_Curve, Deflection: float, U1: float, U2: float, Resolution: float, WithControl: bool) -> None: ...
	@overload
	def Initialize(self, C: Adaptor2d_Curve2d, Deflection: float, U1: float, U2: float, Resolution: float, WithControl: bool) -> None: ...
	def IsAllDone(self) -> bool: ...
	def More(self) -> bool: ...
	def Next(self) -> None: ...
	def Point(self) -> gp_Pnt: ...
	def Value(self) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length
CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length
CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length
CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length
CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length
CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length
CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length
CPnts_AbscissaPoint_Length = CPnts_AbscissaPoint.Length



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.XmlMDF import *
from OCC.Core.Message import *
from OCC.Core.TDF import *
from OCC.Core.XmlObjMgt import *
from OCC.Core.TopTools import *
from OCC.Core.TopLoc import *


class xmlmxcafdoc:
	@staticmethod
	def AddDrivers(aDriverTable: XmlMDF_ADriverTable, anMsgDrv: Message_Messenger) -> None: ...

class XmlMXCAFDoc_AssemblyItemRefDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: XmlObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: XmlObjMgt_Persistent, theRelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_CentroidDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_ColorDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_DatumDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_DimTolDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_GraphNodeDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_LocationDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...
	def SetSharedLocations(self, theLocations: TopTools_LocationSetPtr) -> None: ...
	@overload
	def Translate(self, theLoc: TopLoc_Location, theParent: XmlObjMgt_Element, theMap: XmlObjMgt_SRelocationTable) -> None: ...
	@overload
	def Translate(self, theParent: XmlObjMgt_Element, theLoc: TopLoc_Location, theMap: XmlObjMgt_RRelocationTable) -> bool: ...

class XmlMXCAFDoc_MaterialDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, Source: XmlObjMgt_Persistent, Target: TDF_Attribute, RelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, Source: TDF_Attribute, Target: XmlObjMgt_Persistent, RelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_NoteDriver(XmlMDF_ADriver):
	@overload
	def Paste(self, theSource: XmlObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: XmlObjMgt_Persistent, theRelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_VisMaterialDriver(XmlMDF_ADriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: XmlObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: XmlObjMgt_Persistent, theRelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_VisMaterialToolDriver(XmlMDF_ADriver):
	def __init__(self, theMsgDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: XmlObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: XmlObjMgt_Persistent, theRelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_NoteBinDataDriver(XmlMXCAFDoc_NoteDriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: XmlObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: XmlObjMgt_Persistent, theRelocTable: XmlObjMgt_SRelocationTable) -> None: ...

class XmlMXCAFDoc_NoteCommentDriver(XmlMXCAFDoc_NoteDriver):
	def __init__(self, theMessageDriver: Message_Messenger) -> None: ...
	def NewEmpty(self) -> TDF_Attribute: ...
	@overload
	def Paste(self, theSource: XmlObjMgt_Persistent, theTarget: TDF_Attribute, theRelocTable: XmlObjMgt_RRelocationTable) -> bool: ...
	@overload
	def Paste(self, theSource: TDF_Attribute, theTarget: XmlObjMgt_Persistent, theRelocTable: XmlObjMgt_SRelocationTable) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

xmlmxcafdoc_AddDrivers = xmlmxcafdoc.AddDrivers



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.IntTools import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *
from OCC.Core.TopTools import *
from OCC.Core.Message import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.BRepAdaptor import *

#the following typedef cannot be wrapped as is
BOPTools_Box2dPairSelector = NewType('BOPTools_Box2dPairSelector', Any)
#the following typedef cannot be wrapped as is
BOPTools_Box2dTree = NewType('BOPTools_Box2dTree', Any)
#the following typedef cannot be wrapped as is
BOPTools_Box2dTreeSelector = NewType('BOPTools_Box2dTreeSelector', Any)
#the following typedef cannot be wrapped as is
BOPTools_BoxPairSelector = NewType('BOPTools_BoxPairSelector', Any)
#the following typedef cannot be wrapped as is
BOPTools_BoxTree = NewType('BOPTools_BoxTree', Any)
#the following typedef cannot be wrapped as is
BOPTools_BoxTreeSelector = NewType('BOPTools_BoxTreeSelector', Any)
#the following typedef cannot be wrapped as is
BOPTools_IndexedDataMapOfSetShape = NewType('BOPTools_IndexedDataMapOfSetShape', Any)
#the following typedef cannot be wrapped as is
BOPTools_ListIteratorOfListOfConnexityBlock = NewType('BOPTools_ListIteratorOfListOfConnexityBlock', Any)
#the following typedef cannot be wrapped as is
BOPTools_ListIteratorOfListOfCoupleOfShape = NewType('BOPTools_ListIteratorOfListOfCoupleOfShape', Any)
#the following typedef cannot be wrapped as is
BOPTools_MapIteratorOfMapOfSet = NewType('BOPTools_MapIteratorOfMapOfSet', Any)
#the following typedef cannot be wrapped as is
BOPTools_MapOfSet = NewType('BOPTools_MapOfSet', Any)

class BOPTools_ListOfConnexityBlock:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> BOPTools_ConnexityBlock: ...
    def Last(self) -> BOPTools_ConnexityBlock: ...
    def Append(self, theItem: BOPTools_ConnexityBlock) -> BOPTools_ConnexityBlock: ...
    def Prepend(self, theItem: BOPTools_ConnexityBlock) -> BOPTools_ConnexityBlock: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> BOPTools_ConnexityBlock: ...
    def SetValue(self, theIndex: int, theValue: BOPTools_ConnexityBlock) -> None: ...

class BOPTools_ListOfCoupleOfShape:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> BOPTools_CoupleOfShape: ...
    def Last(self) -> BOPTools_CoupleOfShape: ...
    def Append(self, theItem: BOPTools_CoupleOfShape) -> BOPTools_CoupleOfShape: ...
    def Prepend(self, theItem: BOPTools_CoupleOfShape) -> BOPTools_CoupleOfShape: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> BOPTools_CoupleOfShape: ...
    def SetValue(self, theIndex: int, theValue: BOPTools_CoupleOfShape) -> None: ...

class BOPTools_AlgoTools:
	@staticmethod
	def AreFacesSameDomain(theF1: TopoDS_Face, theF2: TopoDS_Face, theContext: IntTools_Context, theFuzz: Optional[float] = precision_Confusion()) -> bool: ...
	@overload
	@staticmethod
	def ComputeState(thePoint: gp_Pnt, theSolid: TopoDS_Solid, theTol: float, theContext: IntTools_Context) -> TopAbs_State: ...
	@overload
	@staticmethod
	def ComputeState(theVertex: TopoDS_Vertex, theSolid: TopoDS_Solid, theTol: float, theContext: IntTools_Context) -> TopAbs_State: ...
	@overload
	@staticmethod
	def ComputeState(theEdge: TopoDS_Edge, theSolid: TopoDS_Solid, theTol: float, theContext: IntTools_Context) -> TopAbs_State: ...
	@overload
	@staticmethod
	def ComputeState(theFace: TopoDS_Face, theSolid: TopoDS_Solid, theTol: float, theBounds: TopTools_IndexedMapOfShape, theContext: IntTools_Context) -> TopAbs_State: ...
	@staticmethod
	def ComputeStateByOnePoint(theShape: TopoDS_Shape, theSolid: TopoDS_Solid, theTol: float, theContext: IntTools_Context) -> TopAbs_State: ...
	@staticmethod
	def ComputeTolerance(theFace: TopoDS_Face, theEdge: TopoDS_Edge) -> Tuple[bool, float, float]: ...
	@overload
	@staticmethod
	def ComputeVV(theV: TopoDS_Vertex, theP: gp_Pnt, theTolP: float) -> int: ...
	@overload
	@staticmethod
	def ComputeVV(theV1: TopoDS_Vertex, theV2: TopoDS_Vertex, theFuzz: Optional[float] = precision_Confusion()) -> int: ...
	@staticmethod
	def CopyEdge(theEdge: TopoDS_Edge) -> TopoDS_Edge: ...
	@staticmethod
	def CorrectCurveOnSurface(theS: TopoDS_Shape, theMapToAvoid: TopTools_IndexedMapOfShape, theTolMax: Optional[float] = 0.0001, theRunParallel: Optional[bool] = False) -> None: ...
	@staticmethod
	def CorrectPointOnCurve(theS: TopoDS_Shape, theMapToAvoid: TopTools_IndexedMapOfShape, theTolMax: Optional[float] = 0.0001, theRunParallel: Optional[bool] = False) -> None: ...
	@overload
	@staticmethod
	def CorrectRange(aE1: TopoDS_Edge, aE2: TopoDS_Edge, aSR: IntTools_Range, aNewSR: IntTools_Range) -> None: ...
	@overload
	@staticmethod
	def CorrectRange(aE: TopoDS_Edge, aF: TopoDS_Face, aSR: IntTools_Range, aNewSR: IntTools_Range) -> None: ...
	@staticmethod
	def CorrectShapeTolerances(theS: TopoDS_Shape, theMapToAvoid: TopTools_IndexedMapOfShape, theRunParallel: Optional[bool] = False) -> None: ...
	@staticmethod
	def CorrectTolerances(theS: TopoDS_Shape, theMapToAvoid: TopTools_IndexedMapOfShape, theTolMax: Optional[float] = 0.0001, theRunParallel: Optional[bool] = False) -> None: ...
	@staticmethod
	def DTolerance() -> float: ...
	@staticmethod
	def Dimension(theS: TopoDS_Shape) -> int: ...
	@staticmethod
	def Dimensions(theS: TopoDS_Shape) -> Tuple[int, int]: ...
	@staticmethod
	def GetEdgeOff(theEdge: TopoDS_Edge, theFace: TopoDS_Face, theEdgeOff: TopoDS_Edge) -> bool: ...
	@staticmethod
	def GetEdgeOnFace(theEdge: TopoDS_Edge, theFace: TopoDS_Face, theEdgeOnF: TopoDS_Edge) -> bool: ...
	@staticmethod
	def GetFaceOff(theEdge: TopoDS_Edge, theFace: TopoDS_Face, theLCEF: BOPTools_ListOfCoupleOfShape, theFaceOff: TopoDS_Face, theContext: IntTools_Context) -> bool: ...
	@staticmethod
	def IsBlockInOnFace(aShR: IntTools_Range, aF: TopoDS_Face, aE: TopoDS_Edge, aContext: IntTools_Context) -> bool: ...
	@staticmethod
	def IsHole(theW: TopoDS_Shape, theF: TopoDS_Shape) -> bool: ...
	@overload
	@staticmethod
	def IsInternalFace(theFace: TopoDS_Face, theEdge: TopoDS_Edge, theFace1: TopoDS_Face, theFace2: TopoDS_Face, theContext: IntTools_Context) -> int: ...
	@overload
	@staticmethod
	def IsInternalFace(theFace: TopoDS_Face, theEdge: TopoDS_Edge, theLF: TopTools_ListOfShape, theContext: IntTools_Context) -> int: ...
	@overload
	@staticmethod
	def IsInternalFace(theFace: TopoDS_Face, theSolid: TopoDS_Solid, theMEF: TopTools_IndexedDataMapOfShapeListOfShape, theTol: float, theContext: IntTools_Context) -> bool: ...
	@staticmethod
	def IsInvertedSolid(theSolid: TopoDS_Solid) -> bool: ...
	@staticmethod
	def IsMicroEdge(theEdge: TopoDS_Edge, theContext: IntTools_Context, theCheckSplittable: Optional[bool] = True) -> bool: ...
	@staticmethod
	def IsOpenShell(theShell: TopoDS_Shell) -> bool: ...
	@overload
	@staticmethod
	def IsSplitToReverse(theSplit: TopoDS_Shape, theShape: TopoDS_Shape, theContext: IntTools_Context, theError: Optional[int] = None) -> bool: ...
	@overload
	@staticmethod
	def IsSplitToReverse(theSplit: TopoDS_Face, theShape: TopoDS_Face, theContext: IntTools_Context, theError: Optional[int] = None) -> bool: ...
	@overload
	@staticmethod
	def IsSplitToReverse(theSplit: TopoDS_Edge, theShape: TopoDS_Edge, theContext: IntTools_Context, theError: Optional[int] = None) -> bool: ...
	@staticmethod
	def IsSplitToReverseWithWarn(theSplit: TopoDS_Shape, theShape: TopoDS_Shape, theContext: IntTools_Context, theReport: Optional[Message_Report] = None) -> bool: ...
	@staticmethod
	def MakeConnexityBlock(theLS: TopTools_ListOfShape, theMapAvoid: TopTools_IndexedMapOfShape, theLSCB: TopTools_ListOfShape, theAllocator: NCollection_BaseAllocator) -> None: ...
	@overload
	@staticmethod
	def MakeConnexityBlocks(theS: TopoDS_Shape, theConnectionType: TopAbs_ShapeEnum, theElementType: TopAbs_ShapeEnum, theLCB: TopTools_ListOfShape) -> None: ...
	@overload
	@staticmethod
	def MakeConnexityBlocks(theS: TopoDS_Shape, theConnectionType: TopAbs_ShapeEnum, theElementType: TopAbs_ShapeEnum, theLCB: TopTools_ListOfListOfShape, theConnectionMap: TopTools_IndexedDataMapOfShapeListOfShape) -> None: ...
	@overload
	@staticmethod
	def MakeConnexityBlocks(theLS: TopTools_ListOfShape, theConnectionType: TopAbs_ShapeEnum, theElementType: TopAbs_ShapeEnum, theLCB: BOPTools_ListOfConnexityBlock) -> None: ...
	@staticmethod
	def MakeContainer(theType: TopAbs_ShapeEnum, theShape: TopoDS_Shape) -> None: ...
	@staticmethod
	def MakeEdge(theCurve: IntTools_Curve, theV1: TopoDS_Vertex, theT1: float, theV2: TopoDS_Vertex, theT2: float, theTolR3D: float, theE: TopoDS_Edge) -> None: ...
	@overload
	@staticmethod
	def MakeNewVertex(aP1: gp_Pnt, aTol: float, aNewVertex: TopoDS_Vertex) -> None: ...
	@overload
	@staticmethod
	def MakeNewVertex(aV1: TopoDS_Vertex, aV2: TopoDS_Vertex, aNewVertex: TopoDS_Vertex) -> None: ...
	@overload
	@staticmethod
	def MakeNewVertex(aE1: TopoDS_Edge, aP1: float, aE2: TopoDS_Edge, aP2: float, aNewVertex: TopoDS_Vertex) -> None: ...
	@overload
	@staticmethod
	def MakeNewVertex(aE1: TopoDS_Edge, aP1: float, aF2: TopoDS_Face, aNewVertex: TopoDS_Vertex) -> None: ...
	@staticmethod
	def MakePCurve(theE: TopoDS_Edge, theF1: TopoDS_Face, theF2: TopoDS_Face, theCurve: IntTools_Curve, thePC1: bool, thePC2: bool, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@staticmethod
	def MakeSectEdge(aIC: IntTools_Curve, aV1: TopoDS_Vertex, aP1: float, aV2: TopoDS_Vertex, aP2: float, aNewEdge: TopoDS_Edge) -> None: ...
	@staticmethod
	def MakeSplitEdge(aE1: TopoDS_Edge, aV1: TopoDS_Vertex, aP1: float, aV2: TopoDS_Vertex, aP2: float, aNewEdge: TopoDS_Edge) -> None: ...
	@staticmethod
	def MakeVertex(theLV: TopTools_ListOfShape, theV: TopoDS_Vertex) -> None: ...
	@staticmethod
	def OrientEdgesOnWire(theWire: TopoDS_Shape) -> None: ...
	@staticmethod
	def OrientFacesOnShell(theShell: TopoDS_Shape) -> None: ...
	@staticmethod
	def PointOnEdge(aEdge: TopoDS_Edge, aPrm: float, aP: gp_Pnt) -> None: ...
	@staticmethod
	def Sense(theF1: TopoDS_Face, theF2: TopoDS_Face, theContext: IntTools_Context) -> int: ...
	@staticmethod
	def TreatCompound(theS: TopoDS_Shape, theList: TopTools_ListOfShape, theMap: Optional[TopTools_MapOfShape] = None) -> None: ...
	@overload
	@staticmethod
	def UpdateVertex(aIC: IntTools_Curve, aT: float, aV: TopoDS_Vertex) -> None: ...
	@overload
	@staticmethod
	def UpdateVertex(aE: TopoDS_Edge, aT: float, aV: TopoDS_Vertex) -> None: ...
	@overload
	@staticmethod
	def UpdateVertex(aVF: TopoDS_Vertex, aVN: TopoDS_Vertex) -> None: ...

class BOPTools_AlgoTools2D:
	@overload
	@staticmethod
	def AdjustPCurveOnFace(theF: TopoDS_Face, theC3D: Geom_Curve, theC2D: Geom2d_Curve, theC2DA: Geom2d_Curve, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@overload
	@staticmethod
	def AdjustPCurveOnFace(theF: TopoDS_Face, theFirst: float, theLast: float, theC2D: Geom2d_Curve, theC2DA: Geom2d_Curve, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@staticmethod
	def AdjustPCurveOnSurf(aF: BRepAdaptor_Surface, aT1: float, aT2: float, aC2D: Geom2d_Curve, aC2DA: Geom2d_Curve) -> None: ...
	@staticmethod
	def AttachExistingPCurve(aEold: TopoDS_Edge, aEnew: TopoDS_Edge, aF: TopoDS_Face, aCtx: IntTools_Context) -> int: ...
	@staticmethod
	def BuildPCurveForEdgeOnFace(aE: TopoDS_Edge, aF: TopoDS_Face, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@overload
	@staticmethod
	def CurveOnSurface(aE: TopoDS_Edge, aF: TopoDS_Face, aC: Geom2d_Curve, theContext: Optional[IntTools_Context] = IntTools_Context()) -> float: ...
	@overload
	@staticmethod
	def CurveOnSurface(aE: TopoDS_Edge, aF: TopoDS_Face, aC: Geom2d_Curve, theContext: Optional[IntTools_Context] = IntTools_Context()) -> Tuple[float, float, float]: ...
	@staticmethod
	def EdgeTangent(anE: TopoDS_Edge, aT: float, Tau: gp_Vec) -> bool: ...
	@overload
	@staticmethod
	def HasCurveOnSurface(aE: TopoDS_Edge, aF: TopoDS_Face, aC: Geom2d_Curve) -> Tuple[bool, float, float, float]: ...
	@overload
	@staticmethod
	def HasCurveOnSurface(aE: TopoDS_Edge, aF: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def IntermediatePoint(aFirst: float, aLast: float) -> float: ...
	@overload
	@staticmethod
	def IntermediatePoint(anE: TopoDS_Edge) -> float: ...
	@staticmethod
	def IsEdgeIsoline(theE: TopoDS_Edge, theF: TopoDS_Face) -> Tuple[bool, bool]: ...
	@staticmethod
	def Make2D(aE: TopoDS_Edge, aF: TopoDS_Face, aC: Geom2d_Curve, theContext: Optional[IntTools_Context] = IntTools_Context()) -> Tuple[float, float, float]: ...
	@overload
	@staticmethod
	def MakePCurveOnFace(aF: TopoDS_Face, C3D: Geom_Curve, aC: Geom2d_Curve, theContext: Optional[IntTools_Context] = IntTools_Context()) -> float: ...
	@overload
	@staticmethod
	def MakePCurveOnFace(aF: TopoDS_Face, C3D: Geom_Curve, aT1: float, aT2: float, aC: Geom2d_Curve, theContext: Optional[IntTools_Context] = IntTools_Context()) -> float: ...
	@staticmethod
	def PointOnSurface(aE: TopoDS_Edge, aF: TopoDS_Face, aT: float, theContext: Optional[IntTools_Context] = IntTools_Context()) -> Tuple[float, float]: ...

class BOPTools_AlgoTools3D:
	@overload
	@staticmethod
	def DoSplitSEAMOnFace(theESplit: TopoDS_Edge, theFace: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def DoSplitSEAMOnFace(theEOrigin: TopoDS_Edge, theESplit: TopoDS_Edge, theFace: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def GetApproxNormalToFaceOnEdge(aE: TopoDS_Edge, aF: TopoDS_Face, aT: float, aPx: gp_Pnt, aD: gp_Dir, theContext: IntTools_Context) -> bool: ...
	@overload
	@staticmethod
	def GetApproxNormalToFaceOnEdge(theE: TopoDS_Edge, theF: TopoDS_Face, aT: float, aP: gp_Pnt, aDNF: gp_Dir, aDt2D: float) -> bool: ...
	@overload
	@staticmethod
	def GetApproxNormalToFaceOnEdge(theE: TopoDS_Edge, theF: TopoDS_Face, aT: float, aDt2D: float, aP: gp_Pnt, aDNF: gp_Dir, theContext: IntTools_Context) -> bool: ...
	@overload
	@staticmethod
	def GetNormalToFaceOnEdge(aE: TopoDS_Edge, aF: TopoDS_Face, aT: float, aD: gp_Dir, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@overload
	@staticmethod
	def GetNormalToFaceOnEdge(aE: TopoDS_Edge, aF: TopoDS_Face, aD: gp_Dir, theContext: Optional[IntTools_Context] = IntTools_Context()) -> None: ...
	@staticmethod
	def GetNormalToSurface(aS: Geom_Surface, U: float, V: float, aD: gp_Dir) -> bool: ...
	@staticmethod
	def IsEmptyShape(aS: TopoDS_Shape) -> bool: ...
	@staticmethod
	def MinStepIn2d() -> float: ...
	@staticmethod
	def OrientEdgeOnFace(aE: TopoDS_Edge, aF: TopoDS_Face, aER: TopoDS_Edge) -> None: ...
	@overload
	@staticmethod
	def PointInFace(theF: TopoDS_Face, theP: gp_Pnt, theP2D: gp_Pnt2d, theContext: IntTools_Context) -> int: ...
	@overload
	@staticmethod
	def PointInFace(theF: TopoDS_Face, theE: TopoDS_Edge, theT: float, theDt2D: float, theP: gp_Pnt, theP2D: gp_Pnt2d, theContext: IntTools_Context) -> int: ...
	@overload
	@staticmethod
	def PointInFace(theF: TopoDS_Face, theL: Geom2d_Curve, theP: gp_Pnt, theP2D: gp_Pnt2d, theContext: IntTools_Context, theDt2D: Optional[float] = 0.0) -> int: ...
	@overload
	@staticmethod
	def PointNearEdge(aE: TopoDS_Edge, aF: TopoDS_Face, aT: float, aDt2D: float, aP2D: gp_Pnt2d, aPx: gp_Pnt, theContext: IntTools_Context) -> int: ...
	@overload
	@staticmethod
	def PointNearEdge(aE: TopoDS_Edge, aF: TopoDS_Face, aT: float, aDt2D: float, aP2D: gp_Pnt2d, aPx: gp_Pnt) -> int: ...
	@overload
	@staticmethod
	def PointNearEdge(aE: TopoDS_Edge, aF: TopoDS_Face, aT: float, aP2D: gp_Pnt2d, aPx: gp_Pnt, theContext: IntTools_Context) -> int: ...
	@overload
	@staticmethod
	def PointNearEdge(aE: TopoDS_Edge, aF: TopoDS_Face, aP2D: gp_Pnt2d, aPx: gp_Pnt, theContext: IntTools_Context) -> int: ...
	@staticmethod
	def SenseFlag(aNF1: gp_Dir, aNF2: gp_Dir) -> int: ...

class BOPTools_ConnexityBlock:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	def ChangeLoops(self) -> TopTools_ListOfShape: ...
	def ChangeShapes(self) -> TopTools_ListOfShape: ...
	def IsRegular(self) -> bool: ...
	def Loops(self) -> TopTools_ListOfShape: ...
	def SetRegular(self, theFlag: bool) -> None: ...
	def Shapes(self) -> TopTools_ListOfShape: ...

class BOPTools_CoupleOfShape:
	def __init__(self) -> None: ...
	def SetShape1(self, theShape: TopoDS_Shape) -> None: ...
	def SetShape2(self, theShape: TopoDS_Shape) -> None: ...
	def Shape1(self) -> TopoDS_Shape: ...
	def Shape2(self) -> TopoDS_Shape: ...

class BOPTools_Set:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAllocator: NCollection_BaseAllocator) -> None: ...
	@overload
	def __init__(self, theOther: BOPTools_Set) -> None: ...
	def Add(self, theS: TopoDS_Shape, theType: TopAbs_ShapeEnum) -> None: ...
	def Assign(self, Other: BOPTools_Set) -> BOPTools_Set: ...
	def HashCode(self, theUpperBound: int) -> int: ...
	def IsEqual(self, aOther: BOPTools_Set) -> bool: ...
	def NbShapes(self) -> int: ...
	def Shape(self) -> TopoDS_Shape: ...

class BOPTools_SetMapHasher:
	@staticmethod
	def HashCode(theSet: BOPTools_Set, theUpperBound: int) -> int: ...
	@staticmethod
	def IsEqual(aSet1: BOPTools_Set, aSet2: BOPTools_Set) -> bool: ...

#classnotwrapped
class BOPTools_Parallel: ...

#classnotwrapped
class BOPTools_BoxSelector: ...

#classnotwrapped
class BOPTools_BoxSet: ...

#classnotwrapped
class BOPTools_PairSelector: ...

# harray1 classes
# harray2 classes
# hsequence classes

BOPTools_AlgoTools_AreFacesSameDomain = BOPTools_AlgoTools.AreFacesSameDomain
BOPTools_AlgoTools_ComputeState = BOPTools_AlgoTools.ComputeState
BOPTools_AlgoTools_ComputeState = BOPTools_AlgoTools.ComputeState
BOPTools_AlgoTools_ComputeState = BOPTools_AlgoTools.ComputeState
BOPTools_AlgoTools_ComputeState = BOPTools_AlgoTools.ComputeState
BOPTools_AlgoTools_ComputeStateByOnePoint = BOPTools_AlgoTools.ComputeStateByOnePoint
BOPTools_AlgoTools_ComputeTolerance = BOPTools_AlgoTools.ComputeTolerance
BOPTools_AlgoTools_ComputeVV = BOPTools_AlgoTools.ComputeVV
BOPTools_AlgoTools_ComputeVV = BOPTools_AlgoTools.ComputeVV
BOPTools_AlgoTools_CopyEdge = BOPTools_AlgoTools.CopyEdge
BOPTools_AlgoTools_CorrectCurveOnSurface = BOPTools_AlgoTools.CorrectCurveOnSurface
BOPTools_AlgoTools_CorrectPointOnCurve = BOPTools_AlgoTools.CorrectPointOnCurve
BOPTools_AlgoTools_CorrectRange = BOPTools_AlgoTools.CorrectRange
BOPTools_AlgoTools_CorrectRange = BOPTools_AlgoTools.CorrectRange
BOPTools_AlgoTools_CorrectShapeTolerances = BOPTools_AlgoTools.CorrectShapeTolerances
BOPTools_AlgoTools_CorrectTolerances = BOPTools_AlgoTools.CorrectTolerances
BOPTools_AlgoTools_DTolerance = BOPTools_AlgoTools.DTolerance
BOPTools_AlgoTools_Dimension = BOPTools_AlgoTools.Dimension
BOPTools_AlgoTools_Dimensions = BOPTools_AlgoTools.Dimensions
BOPTools_AlgoTools_GetEdgeOff = BOPTools_AlgoTools.GetEdgeOff
BOPTools_AlgoTools_GetEdgeOnFace = BOPTools_AlgoTools.GetEdgeOnFace
BOPTools_AlgoTools_GetFaceOff = BOPTools_AlgoTools.GetFaceOff
BOPTools_AlgoTools_IsBlockInOnFace = BOPTools_AlgoTools.IsBlockInOnFace
BOPTools_AlgoTools_IsHole = BOPTools_AlgoTools.IsHole
BOPTools_AlgoTools_IsInternalFace = BOPTools_AlgoTools.IsInternalFace
BOPTools_AlgoTools_IsInternalFace = BOPTools_AlgoTools.IsInternalFace
BOPTools_AlgoTools_IsInternalFace = BOPTools_AlgoTools.IsInternalFace
BOPTools_AlgoTools_IsInvertedSolid = BOPTools_AlgoTools.IsInvertedSolid
BOPTools_AlgoTools_IsMicroEdge = BOPTools_AlgoTools.IsMicroEdge
BOPTools_AlgoTools_IsOpenShell = BOPTools_AlgoTools.IsOpenShell
BOPTools_AlgoTools_IsSplitToReverse = BOPTools_AlgoTools.IsSplitToReverse
BOPTools_AlgoTools_IsSplitToReverse = BOPTools_AlgoTools.IsSplitToReverse
BOPTools_AlgoTools_IsSplitToReverse = BOPTools_AlgoTools.IsSplitToReverse
BOPTools_AlgoTools_IsSplitToReverseWithWarn = BOPTools_AlgoTools.IsSplitToReverseWithWarn
BOPTools_AlgoTools_MakeConnexityBlock = BOPTools_AlgoTools.MakeConnexityBlock
BOPTools_AlgoTools_MakeConnexityBlocks = BOPTools_AlgoTools.MakeConnexityBlocks
BOPTools_AlgoTools_MakeConnexityBlocks = BOPTools_AlgoTools.MakeConnexityBlocks
BOPTools_AlgoTools_MakeConnexityBlocks = BOPTools_AlgoTools.MakeConnexityBlocks
BOPTools_AlgoTools_MakeContainer = BOPTools_AlgoTools.MakeContainer
BOPTools_AlgoTools_MakeEdge = BOPTools_AlgoTools.MakeEdge
BOPTools_AlgoTools_MakeNewVertex = BOPTools_AlgoTools.MakeNewVertex
BOPTools_AlgoTools_MakeNewVertex = BOPTools_AlgoTools.MakeNewVertex
BOPTools_AlgoTools_MakeNewVertex = BOPTools_AlgoTools.MakeNewVertex
BOPTools_AlgoTools_MakeNewVertex = BOPTools_AlgoTools.MakeNewVertex
BOPTools_AlgoTools_MakePCurve = BOPTools_AlgoTools.MakePCurve
BOPTools_AlgoTools_MakeSectEdge = BOPTools_AlgoTools.MakeSectEdge
BOPTools_AlgoTools_MakeSplitEdge = BOPTools_AlgoTools.MakeSplitEdge
BOPTools_AlgoTools_MakeVertex = BOPTools_AlgoTools.MakeVertex
BOPTools_AlgoTools_OrientEdgesOnWire = BOPTools_AlgoTools.OrientEdgesOnWire
BOPTools_AlgoTools_OrientFacesOnShell = BOPTools_AlgoTools.OrientFacesOnShell
BOPTools_AlgoTools_PointOnEdge = BOPTools_AlgoTools.PointOnEdge
BOPTools_AlgoTools_Sense = BOPTools_AlgoTools.Sense
BOPTools_AlgoTools_TreatCompound = BOPTools_AlgoTools.TreatCompound
BOPTools_AlgoTools_UpdateVertex = BOPTools_AlgoTools.UpdateVertex
BOPTools_AlgoTools_UpdateVertex = BOPTools_AlgoTools.UpdateVertex
BOPTools_AlgoTools_UpdateVertex = BOPTools_AlgoTools.UpdateVertex
BOPTools_AlgoTools2D_AdjustPCurveOnFace = BOPTools_AlgoTools2D.AdjustPCurveOnFace
BOPTools_AlgoTools2D_AdjustPCurveOnFace = BOPTools_AlgoTools2D.AdjustPCurveOnFace
BOPTools_AlgoTools2D_AdjustPCurveOnSurf = BOPTools_AlgoTools2D.AdjustPCurveOnSurf
BOPTools_AlgoTools2D_AttachExistingPCurve = BOPTools_AlgoTools2D.AttachExistingPCurve
BOPTools_AlgoTools2D_BuildPCurveForEdgeOnFace = BOPTools_AlgoTools2D.BuildPCurveForEdgeOnFace
BOPTools_AlgoTools2D_CurveOnSurface = BOPTools_AlgoTools2D.CurveOnSurface
BOPTools_AlgoTools2D_CurveOnSurface = BOPTools_AlgoTools2D.CurveOnSurface
BOPTools_AlgoTools2D_EdgeTangent = BOPTools_AlgoTools2D.EdgeTangent
BOPTools_AlgoTools2D_HasCurveOnSurface = BOPTools_AlgoTools2D.HasCurveOnSurface
BOPTools_AlgoTools2D_HasCurveOnSurface = BOPTools_AlgoTools2D.HasCurveOnSurface
BOPTools_AlgoTools2D_IntermediatePoint = BOPTools_AlgoTools2D.IntermediatePoint
BOPTools_AlgoTools2D_IntermediatePoint = BOPTools_AlgoTools2D.IntermediatePoint
BOPTools_AlgoTools2D_IsEdgeIsoline = BOPTools_AlgoTools2D.IsEdgeIsoline
BOPTools_AlgoTools2D_Make2D = BOPTools_AlgoTools2D.Make2D
BOPTools_AlgoTools2D_MakePCurveOnFace = BOPTools_AlgoTools2D.MakePCurveOnFace
BOPTools_AlgoTools2D_MakePCurveOnFace = BOPTools_AlgoTools2D.MakePCurveOnFace
BOPTools_AlgoTools2D_PointOnSurface = BOPTools_AlgoTools2D.PointOnSurface
BOPTools_AlgoTools3D_DoSplitSEAMOnFace = BOPTools_AlgoTools3D.DoSplitSEAMOnFace
BOPTools_AlgoTools3D_DoSplitSEAMOnFace = BOPTools_AlgoTools3D.DoSplitSEAMOnFace
BOPTools_AlgoTools3D_GetApproxNormalToFaceOnEdge = BOPTools_AlgoTools3D.GetApproxNormalToFaceOnEdge
BOPTools_AlgoTools3D_GetApproxNormalToFaceOnEdge = BOPTools_AlgoTools3D.GetApproxNormalToFaceOnEdge
BOPTools_AlgoTools3D_GetApproxNormalToFaceOnEdge = BOPTools_AlgoTools3D.GetApproxNormalToFaceOnEdge
BOPTools_AlgoTools3D_GetNormalToFaceOnEdge = BOPTools_AlgoTools3D.GetNormalToFaceOnEdge
BOPTools_AlgoTools3D_GetNormalToFaceOnEdge = BOPTools_AlgoTools3D.GetNormalToFaceOnEdge
BOPTools_AlgoTools3D_GetNormalToSurface = BOPTools_AlgoTools3D.GetNormalToSurface
BOPTools_AlgoTools3D_IsEmptyShape = BOPTools_AlgoTools3D.IsEmptyShape
BOPTools_AlgoTools3D_MinStepIn2d = BOPTools_AlgoTools3D.MinStepIn2d
BOPTools_AlgoTools3D_OrientEdgeOnFace = BOPTools_AlgoTools3D.OrientEdgeOnFace
BOPTools_AlgoTools3D_PointInFace = BOPTools_AlgoTools3D.PointInFace
BOPTools_AlgoTools3D_PointInFace = BOPTools_AlgoTools3D.PointInFace
BOPTools_AlgoTools3D_PointInFace = BOPTools_AlgoTools3D.PointInFace
BOPTools_AlgoTools3D_PointNearEdge = BOPTools_AlgoTools3D.PointNearEdge
BOPTools_AlgoTools3D_PointNearEdge = BOPTools_AlgoTools3D.PointNearEdge
BOPTools_AlgoTools3D_PointNearEdge = BOPTools_AlgoTools3D.PointNearEdge
BOPTools_AlgoTools3D_PointNearEdge = BOPTools_AlgoTools3D.PointNearEdge
BOPTools_AlgoTools3D_SenseFlag = BOPTools_AlgoTools3D.SenseFlag
BOPTools_SetMapHasher_HashCode = BOPTools_SetMapHasher.HashCode
BOPTools_SetMapHasher_IsEqual = BOPTools_SetMapHasher.IsEqual
